# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/4/20

"""
阿塞拜疆语
"""

import datetime

now = datetime.datetime.now()
TEST_STRING_DATETIME = {
    '2 saat əvvəl': {
        'accurately': datetime.datetime(
            year=now.year, month=now.month, day=now.day, hour=now.hour) -
                      datetime.timedelta(hours=2),
        'un_accurately': (datetime.datetime(
            year=now.year, month=now.month, day=now.day, hour=now.hour,
            minute=now.minute, second=now.second) -
                          datetime.timedelta(hours=3), datetime.datetime(
            year=now.year, month=now.month, day=now.day, hour=now.hour,
            minute=now.minute, second=now.second) -
                          datetime.timedelta(hours=2)),
    }
}



# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
卢旺达语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r'Ukwa kane', '4月'),
    (r'Iminota', '分钟'),
]
FUZZY_REGEX_LIST = []


#!/usr/bin/env python
# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/3/24
import copy
import os
import glob
import importlib
import re

from .utils import get_sort_dict

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

STRING_DATETIME_CLEAR_REGEX = [
    re.compile(r'\n+'),
    re.compile(r'(\r\n)+'),
    re.compile(r' {2,}')
]
LANG_MAPPING = {
    # 英语
    "en": "en",
    # 中文
    "zh": "zh",
    "zh-CN": "zh",
    "zh-CHS": "zh",
    # 繁体/中国台湾
    "cht": "cht",
    "zh-TW": "cht",
    "zh-CHT": "cht",
    # 德语
    "de": "de",
    # 法语
    "fra": "fra",
    "fr": "fr",
    # 瑞典语
    "swe": 'swe',
    "sv": 'sv',
    # 越南语
    "vie": 'vie',
    "vi": 'vi',
    # 阿塞拜疆语
    'az': 'az',
    # 俄语
    "ru": "ru",
    # 西班牙语
    "spa": "es",
    "es": "es",
    # 索马里语
    "so": "so",
    # 马拉地语
    "mr": "mr",
    "mar": "mr",
    # 乌克兰语
    "uk": "uk",
    # 斯瓦希里语
    "sw": "sw",
    # 土耳其语
    "tr": "tr",
    # 吉尔吉斯语
    "ky": "ky",
    # 乌尔都语
    "ur": "ur",
    # 印尼语
    "id": "_id",
    # 卢旺达语
    "rw": "rw",
    # 僧伽罗语
    "si": "si",
    # 塔吉克语
    "tg": "tg",
    # 印地语
    "hi": "hi",
    # 日语
    "ja": 'ja'
}

TRANSLATE_LANGS = [
    # 阿拉伯语
    'ara',
    'ar',
    # 泰语
    'th'
]

_LANG_LIST_SORT = ['default', 'en', 'zh', 'zht', 'de', 'fra', 'swe',
                   'vie', 'ru', 'es', 'so', 'mr', 'az', "uk", 'sw',
                   'tr', 'ky', 'ur', '_id', 'rw', 'si', 'tg', 'hi',
                   'ja'
                   ]


def compile_regex(regex, flags=0):
    return re.compile(regex, flags)


def compile_regex_list(regex_list, flags=0):
    return [compile_regex(regex, flags) for regex in regex_list]


_LANG_DIR = os.path.join(BASE_DIR, 'langs')
_LANG_FILES = glob.glob(_LANG_DIR + '/*.py')
_LANG_FILES = [filename for filename in _LANG_FILES if
               '__init__' not in filename]
LANG_SUB_TRANSLATE = {}
LANG_ACCURATE_REGEX_LIST = {}
LANG_FUZZY_REGEX_LIST = {}
for lang_file in _LANG_FILES:
    lang = os.path.basename(lang_file).replace('.py', '')
    module_name = 'gggdtparser.langs.' + lang
    module = importlib.import_module(module_name)
    if hasattr(module, 'SUB_TRANSLATE'):
        sub_list = []
        for sub in getattr(module, 'SUB_TRANSLATE'):
            sub_list.append((compile_regex(sub[0]), sub[1]))
        LANG_SUB_TRANSLATE[lang] = sub_list
    if hasattr(module, 'ACCURATE_REGEX_LIST'):
        LANG_ACCURATE_REGEX_LIST[lang] = compile_regex_list(getattr(
            module, 'ACCURATE_REGEX_LIST'), flags=re.M | re.I | re.S)
    if hasattr(module, 'FUZZY_REGEX_LIST'):
        LANG_FUZZY_REGEX_LIST[lang] = compile_regex_list(getattr(
            module, 'FUZZY_REGEX_LIST'), flags=re.M | re.I | re.S)

LANG_ACCURATE_REGEX_LIST = get_sort_dict(
    LANG_ACCURATE_REGEX_LIST, _LANG_LIST_SORT)
LANG_FUZZY_REGEX_LIST = get_sort_dict(
    LANG_FUZZY_REGEX_LIST, _LANG_LIST_SORT)

_SUB_LANG_LIST_SORT = copy.deepcopy(_LANG_LIST_SORT)
(_SUB_LANG_LIST_SORT[0], _SUB_LANG_LIST_SORT[-1]) = (
    _SUB_LANG_LIST_SORT[-1], _SUB_LANG_LIST_SORT[0])
LANG_SUB_TRANSLATE = get_sort_dict(LANG_SUB_TRANSLATE, _SUB_LANG_LIST_SORT)



# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
乌克兰语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r"Січень", "1月"),
    (r"Лютий", "2月"),
    (r"Березень", "3月"),
    (r'квітня|Квітень', '4月'),
    (r"Травень", "5月"),
    (r"Червень", "6月"),
    (r"Липень", "7月"),
    (r"Серпень", "8月"),
    (r"Вересень", "9月"),
    (r"Жовтень", "10月"),
    (r"Листопад", "11月"),
    (r"Грудень", "12月"),

]

FUZZY_REGEX_LIST = [
    r"(?P<bH>\d+)\s*годин\(и\) тому",
    r"(?P<bH>\d+)\s*години\) тому",
    r"(?P<bM>\d+)\s*хвилин\(и\) тому",
    r"(?P<bM>\d+)\s*хвилини\) тому",
]



# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/4/20

"""
阿塞拜疆语
"""

ACCURATE_REGEX_LIST = [

]
FUZZY_REGEX_LIST = []
SUB_TRANSLATE = [
    (r'əvvəl', '前'),
    (r'saat', '小时'),
]



# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/4/26

import sys


def get_sort_dict(d, sort_list=None):
    """
    字典排序
    :param d:
    :param sort_list:
    :return:
    """
    if not sort_list:
        return d
    if sys.version_info >= (3, 9):
        return {k: d[k] for k in sort_list if k in d} | {k: d[
            k] for k in d if k not in sort_list}
    else:
        _d = {k: d[k] for k in sort_list if k in d}
        _d.update({k: d[k] for k in d if k not in sort_list})
        return _d
